"""py33
Loader for Python versions 3.3 and newer.

Copyright (C) 2014  Stijn Wouters  <w.stijn@gmail.com>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

Last modified: 03 August 2014.
By: Stijn Wouters.
"""
from importlib.machinery import SourceFileLoader

from eulerworkbench.loaders import base


class Loader(base.BaseLoader):
    """Loader for Python version 3.3 and newer.
    """

    def __init__(self, module, path):
        """Constructor. This should accept the module name (including package
        name, if any), and the path to that module (including the extension.
        """
        self._loader = SourceFileLoader(module, path)
        return

    def load(self):
        """Actually loads the module.

        Raises `FileNotFoundError` when module not found.
        """
        self._loader.load_module()
        return
